/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.maven;

import javax.management.MBeanServerConnection;
import javax.management.MBeanServerInvocationHandler;
import javax.management.ObjectName;
import javax.management.remote.JMXConnector;
import javax.management.remote.JMXConnectorFactory;
import javax.management.remote.JMXServiceURL;
import java.util.HashMap;

public class PluginUtil
{
   public static TestClusterManagerMBean getTestClusterManager()
   {
      final String JMX_URL = "service:jmx:rmi:///jndi/rmi://localhost:3000/jmxrmi";
      try
      {
         JMXConnector connector = JMXConnectorFactory.connect(new JMXServiceURL(JMX_URL), new HashMap<String, String>());
         ObjectName name = ObjectName.getInstance("activemq:module=test,type=TestClusterManager");
         MBeanServerConnection mbsc = connector.getMBeanServerConnection();
         TestClusterManagerMBean clusterControl = MBeanServerInvocationHandler.newProxyInstance(mbsc,
                                                                                                name,
                                                                                                TestClusterManagerMBean.class,
                                                                                                false);
         clusterControl.getNumNodes();//serves as a validation.
         return clusterControl;
      }
      catch (Exception e)
      {
         return null;
      }
   }

}
